==> insighttoolkit5_5.2.1.orig.tar.xz: InsightToolkit-5.2.1/Documentation/GitHelp.md <==
Git Help
========

Additional information about [Git] may be obtained at these sites:

  * ITK Git cheat sheet
    * [ITK Git PDF desk reference](./GitCheatSheet.pdf)
  * General resources
    * [Git Homepage][Git]
    * [GitHub Try Git In Your Browser](https://try.github.io/)
    * [Git Documentation Wiki](https://git.wiki.kernel.org/index.php/GitDocumentation)
    * [Everyday Git](https://www.kernel.org/pub/software/scm/git/docs/giteveryday.html)
    * [GitHub Services](https://services.github.com/)
  * Development models with Git
    * [A Visual Git Reference](marklodato.github.io/visual-git-guide/)
    * [A successful Git branching model](http://nvie.com/posts/a-successful-git-branching-model/)
      * [PDF](github.com/downloads/nvie/gitflow/Git-branching-model.pdf) version.
    * [LearnGitBranching - Web application designed to help beginners grasp the powerful concepts behind branching](https://learngitbranching.js.org/)
  * Cheat sheets
    * [Git sheat sheet](http://cheat.errtheblog.com/s/git)
    * [GitHub Git cheat sheet](https://services.github.com/on-demand/downloads/github-git-cheat-sheet/)
      * [PDF](https://services.github.com/on-demand/downloads/github-git-cheat-sheet.pdf) version.
  * Git books
    * [Pro Git book](https://git-scm.com/book/en/v2)
      * [Pro Git: Setup](https://git-scm.com/book/en/v2/Getting-Started-First-Time-Git-Setup)
      * [Pro Git: Basic Branching](https://git-scm.com/book/en/v2/Git-Branching-Basic-Branching-and-Merging)
      * [Pro Git: Recording Changes](http://git-scm.com/book/en/Git-Basics-Recording-Changes-to-the-Repository)
      * [Pro Git: Changing the Last Commit](https://git-scm.com/book/en/v2/Git-Tools-Rewriting-History#Changing-the-Last-Commit)
      * [Pro Git: Changing Multiple Commits](https://git-scm.com/book/en/v2/Git-Tools-Rewriting-History#Changing-Multiple-Commit-Messages)
      * [Pro Git: Rebasing](https://git-scm.com/book/en/v2/Git-Branching-Rebasing)



[Git]: https://git-scm.com/

==> insighttoolkit5_5.3.0.orig.tar.xz: InsightToolkit-5.3.0/Documentation/GitHelp.md <==
Git Help
========

Additional information about [Git] may be obtained at these sites:

  * ITK Git cheat sheet
    * [ITK Git PDF desk reference](./GitCheatSheet.pdf)
  * General resources
    * [Git Homepage][Git]
    * [GitHub Try Git In Your Browser](https://try.github.io/)
    * [Git Documentation Wiki](https://git.wiki.kernel.org/index.php/GitDocumentation)
    * [Everyday Git](https://www.kernel.org/pub/software/scm/git/docs/giteveryday.html)
    * [GitHub Services](https://services.github.com/)
  * Development models with Git
    * [A Visual Git Reference](marklodato.github.io/visual-git-guide/)
    * [A successful Git branching model](https://nvie.com/posts/a-successful-git-branching-model/)
      * [PDF](github.com/downloads/nvie/gitflow/Git-branching-model.pdf) version.
    * [LearnGitBranching - Web application designed to help beginners grasp the powerful concepts behind branching](https://learngitbranching.js.org/)
  * Cheat sheets
    * [Git cheat sheet](http://cheat.errtheblog.com/s/git)
    * [GitHub Git cheat sheet](https://services.github.com/on-demand/downloads/github-git-cheat-sheet/)
      * [PDF](https://services.github.com/on-demand/downloads/github-git-cheat-sheet.pdf) version.
  * Git books
    * [Pro Git book](https://git-scm.com/book/en/v2)
      * [Pro Git: Setup](https://git-scm.com/book/en/v2/Getting-Started-First-Time-Git-Setup)
      * [Pro Git: Basic Branching](https://git-scm.com/book/en/v2/Git-Branching-Basic-Branching-and-Merging)
      * [Pro Git: Recording Changes](https://git-scm.com/book/en/Git-Basics-Recording-Changes-to-the-Repository)
      * [Pro Git: Changing the Last Commit](https://git-scm.com/book/en/v2/Git-Tools-Rewriting-History#Changing-the-Last-Commit)
      * [Pro Git: Changing Multiple Commits](https://git-scm.com/book/en/v2/Git-Tools-Rewriting-History#Changing-Multiple-Commit-Messages)
      * [Pro Git: Rebasing](https://git-scm.com/book/en/v2/Git-Branching-Rebasing)



[Git]: https://git-scm.com/
